{ pkgs ? (import <nixpkgs> { })
, callPackage ? pkgs.callPackage
, stdenv ? pkgs.stdenv
, fetchgit ? pkgs.fetchgit
, name ? "brownpaper"
, src ? ./.
}:
let
  filteredSrc = src; # flake only includeds files tracked by git builtins.filterSource pkgs.lib.cleanSourceFilter src;
  crate2nix = fetchGit { url = "https://github.com/kolloch/crate2nix.git"; rev = "2f861db71475b4cf0d266b8d2fd625cccf1e331b"; };
  crate2nix_tools = (if builtins.compareVersions pkgs.crate2nix.version "0.8.0" == 1 then import (pkgs.crate2nix.src + "/tools.nix") else import "${crate2nix}/tools.nix") { inherit pkgs; };
  overrides = with pkgs; let
    clang = llvmPackages_10.clang;
    libclang = llvmPackages_10.libclang;
  in
  defaultCrateOverrides // rec {
    nettle-sys = attrs: rec {
      nativeBuildInputs = [ clang pkg-config ];
      buildInputs = [ nettle ];
      LIBCLANG_PATH = "${libclang}/lib";
    };
    brownpaper = attrs: {
      buildInputs = [ gmp (pkgs.callPackage "${crate2nix}/crate2nix/Cargo.nix" { strictDeprecation = true; }) ];
    };
  };
  client = with pkgs; runCommandLocal "brownpaper" {
    script = "${filteredSrc}/bp.sh";
    nativeBuildInputs = [ makeWrapper ];
  } ''
    makeWrapper $script $out/bin/brownpaper \
    --prefix PATH : ${lib.makeBinPath [ bash curl gnupg ]}
  '';
in
{ server = (callPackage (crate2nix_tools.generatedCargoNix { inherit name; src = filteredSrc; }) { inherit pkgs; defaultCrateOverrides = overrides; }).rootCrate.build;  inherit client; }
